Learn R Programming

remedy (version 0.1.0)

chunknamer: Interactively Add Names to Chunks

Description

Addin that add in bulk a names to unnamed chunks in a Rmarkdown document in the source editor.

Usage

chunknamer()

Arguments

Details

By default the addin will use "remedy" as the stem of the chunk names. this an be changed using remedy_opts$set(name='ANOTHER NAME'). The names are then added in sequential order using an